//Copyright 2011 Desire2Learn Incorporated
//
//Licensed under the Apache License, Version 2.0 (the "License");
//you may not use this file except in compliance with the License.
//You may obtain a copy of the License at
//
//http://www.apache.org/licenses/LICENSE-2.0
//
//Unless required by applicable law or agreed to in writing, software
//distributed under the License is distributed on an "AS IS" BASIS,
//WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//See the License for the specific language governing permissions and
//limitations under the License.


#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "D2LModuleAssistant.h"
#import "D2LModuleScreenshotAssistant.h"

/**
 * Your module must provide a class implementing this protocol.  An
 * instance of that class is created for each time your module is
 * included in the host application.  Instances of your module are
 * specialized through the configuration parameters exposed through
 * the D2LModuleAssistant object provided when the instance is initialized.
 */

@protocol D2LModule <NSObject>

@required

/**
 * Initializes the object.
 *
 * @param assistant - An object providing information and services specific
 * to this module instance. You should retain this object to access its
 * services later.
 *
 * @return A reference to the newly instantiated module object.
 */
- (id)initWithAssistant:(id<D2LModuleAssistant>)assistant;

/**
 * Returns the root view controller of your module.  When your module is
 * opened, the view controller object returned by this method will be
 * set as the root view controller of the application window.
 *
 * @return The root view controller of your module.
 */
- (UIViewController *)getViewController;


@optional

/**
 * This method is called the first time the user opens the module after
 * the application has been launched.  (If the user closes the host
 * application, then reopens it and launches the module, this method will
 * be called again.)
 */
- (void)moduleWillOpenFirstTime;

/**
 * This method is called each time the user opens your module, before
 * retrieving and displaying the root view controller.
 */
- (void)moduleWillOpen;

/**
 * This method is called when your module is closed.
 */
- (void)moduleWillClose;

/**
 * This method is called when the host application is suspended while your module
 * is currently open.
 */
- (void)moduleWillSuspend;

/**
 * This method is called when the host application resumes directly into
 * your module (from having suspended the app while the module was open).
 */
- (void)moduleWillResume;

/**
 * This method is called when the host application is suspended, whether or not
 * your module is currently open.
 */
- (void)applicationWillSuspend;

/**
 * This method is called when the host application resumes, whether or not
 * your module is currently open.
 */
- (void)applicationWillResume;

/**
 * AppBuilder has a process to automatically generate screenshots of a Campus Life
 * app and its modules.  By default, a single picture of a module is taken a few
 * seconds after it launches.  To manually control how screenshots are taken of
 * your module, implement this method.  When called, your module should begin the-
 * process of automatically generating screenshots.  When finished, you should 
 * call the appropriate method of the screenshot assistant object.
 * 
 * If this method is implemented but no screenshot is taken for an extended period
 * of time, the screenshotting process for this module will be aborted.
 *
 * @param screenshotAssistant - a helper object with methods to take screenshots
 *                              and notify when the process is complete.
 */
- (void)takeScreenshots:(id<D2LModuleScreenshotAssistant>)screenshotAssistant;
@end
