//Copyright 2011 Desire2Learn Incorporated
//
//Licensed under the Apache License, Version 2.0 (the "License");
//you may not use this file except in compliance with the License.
//You may obtain a copy of the License at
//
//http://www.apache.org/licenses/LICENSE-2.0
//
//Unless required by applicable law or agreed to in writing, software
//distributed under the License is distributed on an "AS IS" BASIS,
//WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//See the License for the specific language governing permissions and
//limitations under the License.


#import <Foundation/Foundation.h>

/**
 * On initialization, your module receives an assistant object implementing
 * this protocol.  This object provides services specific to an instance
 * of your module.  (Your module may have multiple instances within the
 * application; each receives its own assistant.)
 */

@protocol D2LModuleAssistant <NSObject>

/**
 * Retrieves the title of the module instance (that is, the text of the 
 * button on the app main menu that launched it).
 *
 * @return The title of the module.
 */
- (NSString *)title;

/**
 * Checks if an option was provided to the module.
 *
 * @param option - The name of the parameter to check.
 * @return YES if the option exists; NO otherwise.
 */
- (BOOL)hasOption:(NSString *)option;

/**
 * Retrieves the value of a module configuration option as a string.
 *
 * @param option - The name of the parameter to retrieve.
 * @return The value of the parameter as a string.
 */
- (NSString *)stringForOption:(NSString *)option;

/**
 * Retrieves the value of a module configuration option as a number.
 *
 * @param option - The name of the parameter to retrieve.
 * @return The value of the parameter as a number.
 */
- (NSNumber *)numberForOption:(NSString *)option;

/**
 * Retrieves the value of a module configuration option as a boolean.
 *
 * @param option - The name of the parameter to retrieve.
 * @return The value of the parameter as a boolean, or NO if the option
 *         value is missing or invalid.
 */
- (BOOL)boolForOption:(NSString *)option;

/**
 * Retrieves the value of a module configuration option as a URL.
 *
 * @param option - The name of the parameter to retrieve.
 * @return The value of the parameter as a URL.
 */
- (NSURL *)urlForOption:(NSString *)option;

/**
 * Retrieves the local file URL for a file asset that was uploaded in
 * AppBuilder for use by the module.
 *
 * @param option - The name of the parameter to retrieve.
 * @return The URL of the file provided for the parameter.
 */
- (NSURL *)localFileURLForOption:(NSString *)option;

/**
 * Sets the badge number that is displayed on your module's button on the
 * application main menu.
 *
 * @param number - The number to display.  The badge will not be visible
 * if the number is 0 or negative.
 */
- (void)setBadgeNumber:(NSInteger)number;

/**
 * Closes the module and returns the user to the application's
 * main menu.  (Your module must provide a way for the user to return
 * to the main menu.)
 */
- (void)dismiss;

/**
 * Retrieves a path to a subdirectory of the application's Library/Application Support folder
 * specific to this module instance.
 *
 * @return The path to this module's Application Support folder.
 */
- (NSString *) applicationSupportPath;

/**
 * Retrieves a path to a subdirectory of the application's Library/Caches folder
 * specific to this module instance.
 *
 * @return The path to this module's Caches folder.
 */
- (NSString *) cachesPath;

/**
 * Retrieves a path to a subdirectory of the application's Documents folder
 * specific to this module instance.
 *
 * @return The path to this module's Documents folder.
 */
- (NSString *) documentsPath;

/**
 * Retrieves a path to a subdirectory of the application's tmp folder
 * specific to this module instance.
 *
 * @return The path to this module's tmp folder.
 */
- (NSString *) tmpPath;


@end
