//Copyright 2011 Desire2Learn Incorporated
//
//Licensed under the Apache License, Version 2.0 (the "License");
//you may not use this file except in compliance with the License.
//You may obtain a copy of the License at
//
//http://www.apache.org/licenses/LICENSE-2.0
//
//Unless required by applicable law or agreed to in writing, software
//distributed under the License is distributed on an "AS IS" BASIS,
//WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//See the License for the specific language governing permissions and
//limitations under the License.


#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>

/**
 * App creators can specify simple branding information while creating
 * their app, such as background images, custom tint colors, etc.
 * While it is not required that your module use the host application's branding
 * settings, it is a way to make your module feel more unified with
 * the rest of the application.
 *
 * The shared brand object provides methods that allow you to access
 * that branding information and style your UI controls to match.
 */

@interface D2LModuleBrand : NSObject

/**
 * Returns the shared branding object.
 */
+ (D2LModuleBrand *)sharedBrand;

/**
 * Applies the application's module portrait background image to the given view.
 *
 * @param view - The view to apply the image to.
 */
- (void)applyPortraitBackgroundToView:(UIView *)view;

/**
 * Applies the application's module landscape background image to the given view.
 *
 * @param view - The view to apply the image to.
 */
- (void)applyLandscapeBackgroundToView:(UIView *)view;

/**
 * Brands the text and shadow colors of the given label.  Meant to be used on
 * labels that appear directly overtop the module background image.
 *
 * @param label - The label to brand.
 */
- (void)applyStyleToLabel:(UILabel *)label;

/**
 * Brands the tint color of the given navigation bar.
 *
 * @param navigationBar - the navigation bar to brand.
 */
- (void)applyStyleToNavigationBar:(UINavigationBar *)navigationBar;

/**
 * Brands the tint color of the given search bar.
 *
 * @param searchBar - The search bar to brand.
 */
- (void)applyStyleToSearchBar:(UISearchBar *)searchBar;

/**
 * Brands the tint color of the given toolbar.
 *
 * @param toolbar - The toolbar to brand.
 */
- (void)applyStyleToToolbar:(UIToolbar *)toolbar;

/**
 * Brands the text and background colors of the given table view cell.  Meant for
 * iOS preset table view cell styles, and not custom table view cells.
 *
 * @param tableViewCell - The table view cell to brand.
 */
- (void)applyStyleToTableViewCell:(UITableViewCell *)tableViewCell;

/**
 * Returns the brand color corresponding to a key string.  Every application branding
 * color can be accessed individually through this method, though when possible
 * you should use one of the provided "applyStyle" methods instead.
 *
 * @param key - The key string for the color to retrieve.
 * @return The color corresponding to the given key.
 */
- (UIColor *)colorForKey:(NSString *)key;

@end
